from si_fab import all as pdk
from ipkiss3 import all as i3
import numpy as np
import os
import pylab as plt

grating = pdk.FC_TE_1550()
spacings = np.linspace(0, 10, 5)
insts = dict()

bend_radius = 20.0
spacing = 5.0
spacing_x = 0 * bend_radius
spacing_y = 2 * bend_radius
specs = []

for cnt, sp in enumerate(spacings):
    gr_up = "gr_up_{}".format(cnt)
    gr_down = "gr_down_{}".format(cnt)
    gr_up_port = "{}:out".format(gr_up)
    gr_down_port = "{}:out".format(gr_down)
    insts[gr_up] = grating
    insts[gr_down] = grating
    specs.append(i3.Place(gr_up_port, (spacing_x, (-cnt / 2.0 - 0.5) * spacing_y)))
    specs.append(i3.Place(gr_down_port, (0, (cnt / 2.0 + 0.5) * spacing_y)))

    specs.append(
        i3.ConnectManhattan(
            gr_up_port,
            gr_down_port,
            control_points=[i3.V(i3.START + bend_radius + (cnt + 1) * spacing)],
            bend_radius=bend_radius,
            min_straight=0.0,
        )
    )


cell = i3.Circuit(
    insts=insts,
    specs=specs,
)

lv = cell.Layout()

fig2 = lv.visualize(show=True, annotate=False)
plt.title("Grating Array")
fig2.savefig(
    os.path.join("grating_array.png"),
    transparent=True,
    bbox_inches="tight",
)
